"""
.. currentmodule:: flytekitplugins.pod

This package contains things that are useful when extending Flytekit.

.. autosummary::
   :template: custom.rst
   :toctree: generated/

   Pod
"""

from .task import Pod
